@@ -2,25 +2,38 @@ from sqlobject.dbconnection import DBAPI
 from sqlobject import col
 import re
 
-sqlmodule = None
-
 class MSSQLConnection(DBAPI):
 
     supportTransactions = True
     dbName = 'mssql'
     schemes = [dbName]
 
+    limit_re = re.compile('^\s*(select )(.*)', re.IGNORECASE)
+
     def __init__(self, db, user, password='', host='localhost',
                  autoCommit=0, **kw):
-        global sqlmodule
-        if not sqlmodule:
+        drivers = kw.pop('driver', None) or \
+            kw.pop('backend', None) or 'adodb,pymssql'
+        for driver in drivers.split(','):
+            driver = driver.strip()
+            if not driver:
+                continue
             try:
-                import adodbapi as sqlmodule
+                if driver in ('adodb', 'adodbapi'):
+                    import adodbapi as sqlmodule
+                elif driver == 'pymssql':
+                    import pymssql as sqlmodule
+                else:
+                    raise ValueError('Unknown MSSQL driver "%s", expected adodb or pymssql' % driver)
             except ImportError:
-                import pymssql as sqlmodule
+                pass
+            else:
+                break
+        else:
+            raise ImportError('Cannot find an MSSQL driver, tried %s' % drivers)
+        self.module = sqlmodule
 
         if sqlmodule.__name__ == 'adodbapi':
-            import adodbapi as sqlmodule
             self.dbconnection = sqlmodule.connect
             # ADO uses unicode only (AFAIK)
             self.usingUnicodeStrings = True
@@ -57,9 +70,7 @@ class MSSQLConnection(DBAPI):
         self.db = db
         self.user = user
         self.password = password
-        self.limit_re = re.compile('^\s*(select )(.*)', re.IGNORECASE)
         self.password = password
-        self.module = sqlmodule
         self._can_use_max_types = None
         DBAPI.__init__(self, **kw)
 
@@ -217,8 +228,7 @@ class MSSQLConnection(DBAPI):
                                 % tableName)
         results = []
         for field, size, t, precision, scale, nullAllowed, default, defaultText, is_identity in colData:
-            # Seems strange to skip the pk column?  What if it's not 'id'?
-            if field == 'id':
+            if field == soClass.sqlmeta.idName:
                 continue
             # precision is needed for decimal columns
             colClass, kw = self.guessClass(t, size, precision, scale)
